==> oil-0.22.0.tar.gz: _devbuild/gen/help_meta.py <==
TOPICS = {'ARGV': 'special-var',
 'BASHOPTS': 'special-var',
 'BASHPID': 'special-var',
 'BASH_LINENO': 'special-var',
 'BASH_REMATCH': 'special-var',
 'BASH_SOURCE': 'special-var',
 'BashArray': 'type-method',
 'BashAssoc': 'type-method',
 'Bool': 'type-method',
 'BoundFunc': 'type-method',
 'BuiltinFunc': 'type-method',
 'CDPATH': 'special-var',
 'COMPREPLY': 'special-var',
 'COMP_ARGV': 'special-var',
 'COMP_CWORD': 'special-var',
 'COMP_LINE': 'special-var',
 'COMP_POINT': 'special-var',
 'COMP_WORDBREAKS': 'special-var',
 'COMP_WORDS': 'special-var',
 'Command': 'type-method',
 'DEBUG': 'plugin',
 'ENV': 'special-var',
 'ERR': 'plugin',
 'EUID': 'special-var',
 'EXIT': 'plugin',
 'Expr': 'type-method',
 'FUNCNAME': 'special-var',
 'Float': 'type-method',
 'GLOBIGNORE': 'special-var',
 'HISTFILE': 'special-var',
 'HOME': 'special-var',
 'HOSTNAME': 'special-var',
 'IFS': 'special-var',
 'Int': 'type-method',
 'LANG': 'special-var',
 'LINENO': 'special-var',
 'List/append': 'type-method',
 'Null': 'type-method',
 'OILS_GC_ON_EXIT': 'special-var',
 'OILS_GC_STATS': 'special-var',
 'OILS_GC_STATS_FD': 'special-var',
 'OILS_GC_THRESHOLD': 'special-var',
 'OILS_VERSION': 'special-var',
 'OLDPWD': 'special-var',
 'OPTARG': 'special-var',
 'OPTERR': 'special-var',
 'OPTIND': 'special-var',
 'OSTYPE': 'special-var',
 'PATH': 'special-var',
 'PIPESTATUS': 'special-var',
 'PPID': 'special-var',
 'PROMPT_COMMAND': 'plugin',
 'PS1': 'plugin',
 'PS2': 'plugin',
 'PS3': 'plugin',
 'PS4': 'plugin',
 'PWD': 'special-var',
 'RANDOM': 'special-var',
 'REPLY': 'special-var',
 'RETURN': 'plugin',
 'SECONDS': 'special-var',
 'SHELLOPTS': 'special-var',
 'SHX_indent': 'special-var',
 'SHX_pid_str': 'special-var',
 'SHX_punct': 'special-var',
 'SIGINT': 'plugin',
 'SIGQUIT': 'plugin',
 'SIGTERM': 'plugin',
 'SIGTTIN': 'plugin',
 'SIGTTOU': 'plugin',
 'SIGWINCH': 'plugin',
 'UID': 'special-var',
 'YSH_HISTFILE': 'special-var',
 '_end': 'builtin-func',
 '_error': 'special-var',
 '_group': 'builtin-func',
 '_pipeline_status': 'special-var',
 '_process_sub_status': 'special-var',
 '_reply': 'special-var',
 '_start': 'builtin-func',
 '_status': 'special-var',
 '_this_dir': 'special-var',
 'abs': 'builtin-func',
 'accum': 'type-method',
 'alias': 'builtin-cmd',
 'all': 'builtin-func',
 'ampersand': 'cmd-lang',
 'and': 'cmd-lang',
 'any': 'builtin-func',
 'append': 'index',
 'arg': 'builtin-cmd',
 'arith-context': 'mini-lang',
 'arith-sub': 'word-lang',
 'ascii-control-chars': 'front-end',
 'ascii-whitespace': 'front-end',
 'assign': 'expr-lang',
 'atom-literal': 'expr-lang',
 'aug-assign': 'expr-lang',
 'b-prefix': 'j8',
 'bang': 'cmd-lang',
 'block-arg': 'cmd-lang',
 'block-expr': 'expr-lang',
 'bool': 'builtin-func',
 'bool-expr': 'mini-lang',
 'bool-infix': 'mini-lang',
 'bool-other': 'mini-lang',
 'bool-path': 'mini-lang',
 'bool-str': 'mini-lang',
 'boolstatus': 'builtin-cmd',
 'braces': 'mini-lang',
 'break': 'cmd-lang',
 'builtin': 'builtin-cmd',
 'call': 'ysh-cmd',
 'captureStdout': 'type-method',
 'case': 'cmd-lang',
 'cat-em': 'front-end',
 'cd': 'builtin-cmd',
 'char-escapes': 'mini-lang',
 'chr': 'builtin-func',
 'class-literal': 'expr-lang',
 'cmd/append': 'builtin-cmd',
 'cmd/type': 'builtin-cmd',
 'colon': 'cmd-lang',
 'column-attrs': 'j8',
 'column-types': 'j8',
 'command': 'builtin-cmd',
 'command-sub': 'word-lang',
 'comment': 'front-end',
 'compadjust': 'builtin-cmd',
 'compexport': 'builtin-cmd',
 'compgen': 'builtin-cmd',
 'complete': 'plugin',
 'compopt': 'builtin-cmd',
 'concat': 'expr-lang',
 'config': 'front-end',
 'const': 'ysh-cmd',
 'continue': 'cmd-lang',
 'ctx': 'builtin-cmd',
 'dashglob': 'option',
 'dbracket': 'cmd-lang',
 'declare': 'osh-assign',
 'dict': 'builtin-func',
 'dict-literal': 'expr-lang',
 'dirs': 'builtin-cmd',
 'doc-comment': 'front-end',
 'dparen': 'cmd-lang',
 'echo': 'builtin-cmd',
 'enable': 'builtin-cmd',
 'end': 'type-method',
 'endsWith': 'type-method',
 'equal': 'ysh-cmd',
 'erase': 'type-method',
 'err-j8-lines-decode': 'errors',
 'err-j8-lines-encode': 'errors',
 'err-j8-str-decode': 'errors',
 'err-j8-str-encode': 'errors',
 'err-json-decode': 'errors',
 'err-json-encode': 'errors',
 'err-json8-decode': 'errors',
 'err-json8-encode': 'errors',
 'err-utf8-decode': 'errors',
 'err-utf8-encode': 'errors',
 'error': 'builtin-cmd',
 'eval': 'type-method',
 'evalExpr': 'builtin-func',
 'evalHay': 'builtin-func',
 'eval_unsafe_arith': 'option',
 'exec': 'builtin-cmd',
 'exit': 'cmd-lang',
 'exit-codes': 'front-end',
 'export': 'osh-assign',
 'expr-literal': 'expr-lang',
 'expr-splice': 'word-lang',
 'expr-sub': 'word-lang',
 'extend': 'type-method',
 'extglob': 'mini-lang',
 'false': 'cmd-lang',
 'fat-arrow': 'expr-lang',
 'fg': 'builtin-cmd',
 'find': 'type-method',
 'flag': 'builtin-cmd',
 'float': 'builtin-func',
 'float-lit': 'expr-lang',
 'fopen': 'builtin-cmd',
 'for': 'cmd-lang',
 'for-expr-sh': 'cmd-lang',
 'fork': 'builtin-cmd',
 'forkwait': 'builtin-cmd',
 'fromJson': 'builtin-func',
 'fromJson8': 'builtin-func',
 'func': 'ysh-cmd',
 'func-call': 'expr-lang',
 'func/type': 'builtin-func',
 'get': 'type-method',
 'getVar': 'builtin-func',
 'getopts': 'builtin-cmd',
 'glob': 'type-method',
 'glob-pat': 'mini-lang',
 'group': 'type-method',
 'hash': 'builtin-cmd',
 'hay': 'builtin-cmd',
 'haynode': 'builtin-cmd',
 'help': None,
 'here-doc': 'cmd-lang',
 'history': 'builtin-cmd',
 'histsub': 'mini-lang',
 'if': 'cmd-lang',
 'inc': 'type-method',
 'indexOf': 'type-method',
 'insert': 'type-method',
 'int': 'builtin-func',
 'int-literal': 'expr-lang',
 'is-main': 'builtin-cmd',
 'j8-escape': 'j8',
 'jobs': 'builtin-cmd',
 'join': 'builtin-func',
 'json': 'builtin-cmd',
 'json-escape': 'j8',
 'json-string': 'j8',
 'json8': 'builtin-cmd',
 'json8-comment': 'j8',
 'json8-dict': 'j8',
 'json8-list': 'j8',
 'json8-num': 'j8',
 'json8-str': 'j8',
 'keys': 'type-method',
 'kill': 'builtin-cmd',
 'lazy-expr-arg': 'cmd-lang',
 'leftMatch': 'type-method',
 'len': 'builtin-func',
 'line-continuation': 'front-end',
 'line-editing': 'front-end',
 'list': 'builtin-func',
 'list-literal': 'expr-lang',
 'local': 'osh-assign',
 'lower': 'type-method',
 'mapfile': 'builtin-cmd',
 'match-ops': 'expr-lang',
 'max': 'builtin-func',
 'maybe': 'builtin-func',
 'min': 'builtin-func',
 'module': 'builtin-cmd',
 'multiline-command': 'front-end',
 'named-class': 'expr-lang',
 'no-prefix': 'j8',
 'nullglob': 'option',
 'oils-usage': None,
 'op-format': 'word-lang',
 'op-index': 'word-lang',
 'op-precedence': 'expr-lang',
 'op-replace': 'word-lang',
 'op-slice': 'word-lang',
 'op-strip': 'word-lang',
 'op-test': 'word-lang',
 'opts-internal': 'option',
 'opts-redefine': 'option',
 'or': 'cmd-lang',
 'ord': 'builtin-func',
 'osh-chapters': None,
 'osh-string': 'word-lang',
 'osh-usage': None,
 'parseArgs': 'builtin-cmd',
 'parseHay': 'builtin-func',
 'parse_ignored': 'option',
 'parse_triple_quote': 'option',
 'parse_ysh_string': 'option',
 'parser': 'builtin-cmd',
 'pipe': 'cmd-lang',
 'pop': 'type-method',
 'popd': 'builtin-cmd',
 'pp': 'builtin-cmd',
 'printf': 'builtin-cmd',
 'proc': 'ysh-cmd',
 'proc-sub': 'word-lang',
 'promptVal': 'type-method',
 'push-registers': 'builtin-cmd',
 'pushd': 'builtin-cmd',
 'pwd': 'builtin-cmd',
 'range': 'expr-lang',
 're-capture': 'expr-lang',
 're-compound': 'expr-lang',
 're-flags': 'expr-lang',
 're-literal': 'expr-lang',
 're-multiline': 'expr-lang',
 're-primitive': 'expr-lang',
 're-repeat': 'expr-lang',
 're-splice': 'expr-lang',
 'read': 'builtin-cmd',
 'readarray': 'builtin-cmd',
 'readonly': 'osh-assign',
 'redir-desc': 'cmd-lang',
 'redir-file': 'cmd-lang',
 'regex': 'mini-lang',
 'remove': 'type-method',
 'renderPrompt': 'plugin',
 'repeat': 'builtin-func',
 'replace': 'type-method',
 'rest': 'builtin-cmd',
 'return': 'cmd-lang',
 'reverse': 'type-method',
 'round': 'builtin-func',
 'runes': 'builtin-func',
 'runproc': 'builtin-cmd',
 'search': 'type-method',
 'semicolon': 'cmd-lang',
 'set': 'builtin-cmd',
 'setValue': 'type-method',
 'setglobal': 'ysh-cmd',
 'setvar': 'ysh-cmd',
 'sh-append': 'osh-assign',
 'sh-arith': 'mini-lang',
 'sh-array': 'osh-assign',
 'sh-assign': 'osh-assign',
 'sh-assoc': 'osh-assign',
 'sh-bitwise': 'mini-lang',
 'sh-block': 'cmd-lang',
 'sh-func': 'cmd-lang',
 'sh-logical': 'mini-lang',
 'sh-numbers': 'mini-lang',
 'shSplit': 'builtin-func',
 'sha1dc': 'builtin-func',
 'sha256': 'builtin-func',
 'shift': 'osh-assign',
 'shopt': 'builtin-cmd',
 'shvar': 'builtin-cmd',
 'shvarGet': 'builtin-func',
 'sigpipe_status_ok': 'option',
 'simple-command': 'cmd-lang',
 'source': 'builtin-cmd',
 'split': 'builtin-func',
 'start': 'type-method',
 'startsWith': 'type-method',
 'startup': 'front-end',
 'str': 'builtin-func',
 'str-template': 'expr-lang',
 'strcmp': 'builtin-func',
 'strftime': 'type-method',
 'strict:all': 'option',
 'strict_control_flow': 'option',
 'strict_nameref': 'option',
 'strict_tilde': 'option',
 'subshell': 'cmd-lang',
 'sum': 'builtin-func',
 'surrogate-pair': 'j8',
 'tagged-str': 'word-lang',
 'test': 'builtin-cmd',
 'thin-arrow': 'expr-lang',
 'tilde-sub': 'word-lang',
 'time': 'type-method',
 'times': 'builtin-cmd',
 'toJson': 'builtin-func',
 'toJson8': 'builtin-func',
 'trap': 'builtin-cmd',
 'trim': 'type-method',
 'trimEnd': 'type-method',
 'trimStart': 'type-method',
 'triple-quoted': 'word-lang',
 'true': 'cmd-lang',
 'try': 'builtin-cmd',
 'type': 'index',
 'typed-arg': 'cmd-lang',
 'typeset': 'osh-assign',
 'u-prefix': 'j8',
 'ulimit': 'builtin-cmd',
 'umask': 'builtin-cmd',
 'unalias': 'builtin-cmd',
 'unquoted-line': 'j8',
 'unset': 'osh-assign',
 'until': 'cmd-lang',
 'upper': 'type-method',
 'use': 'builtin-cmd',
 'values': 'type-method',
 'var': 'ysh-cmd',
 'var-splice': 'word-lang',
 'var-sub': 'word-lang',
 'wait': 'builtin-cmd',
 'while': 'cmd-lang',
 'write': 'builtin-cmd',
 'ysh-arith': 'expr-lang',
 'ysh-attr': 'expr-lang',
 'ysh-bitwise': 'expr-lang',
 'ysh-case': 'cmd-lang',
 'ysh-cd': 'builtin-cmd',
 'ysh-chapters': None,
 'ysh-compare': 'expr-lang',
 'ysh-echo': 'builtin-cmd',
 'ysh-equals': 'expr-lang',
 'ysh-for': 'cmd-lang',
 'ysh-format': 'word-lang',
 'ysh-if': 'cmd-lang',
 'ysh-in': 'expr-lang',
 'ysh-index': 'expr-lang',
 'ysh-logical': 'expr-lang',
 'ysh-printf': 'word-lang',
 'ysh-read': 'builtin-cmd',
 'ysh-return': 'ysh-cmd',
 'ysh-shopt': 'builtin-cmd',
 'ysh-slice': 'expr-lang',
 'ysh-string': 'word-lang',
 'ysh-ternary': 'expr-lang',
 'ysh-usage': None,
 'ysh-while': 'cmd-lang',
 'ysh:all': 'option',
 'ysh:upgrade': 'option'}


from typing import Dict

def TopicMetadata():
  # type: () -> Dict[str, str]
  return TOPICS

==> oil-0.24.0.tar.gz: _devbuild/gen/help_meta.py <==
TOPICS = {'ARGV': 'special-var',
 'BASHOPTS': 'special-var',
 'BASHPID': 'special-var',
 'BASH_LINENO': 'special-var',
 'BASH_REMATCH': 'special-var',
 'BASH_SOURCE': 'special-var',
 'BashArray': 'type-method',
 'BashAssoc': 'type-method',
 'Bool': 'type-method',
 'BoundFunc': 'type-method',
 'BuiltinFunc': 'type-method',
 'BuiltinProc': 'type-method',
 'CDPATH': 'special-var',
 'COMPREPLY': 'special-var',
 'COMP_ARGV': 'special-var',
 'COMP_CWORD': 'special-var',
 'COMP_LINE': 'special-var',
 'COMP_POINT': 'special-var',
 'COMP_WORDBREAKS': 'special-var',
 'COMP_WORDS': 'special-var',
 'Command': 'type-method',
 'CommandFrag': 'type-method',
 'DEBUG': 'plugin',
 'Dict': 'type-method',
 'Dict/clear': 'type-method',
 'ENV': 'special-var',
 'ERR': 'plugin',
 'EUID': 'special-var',
 'EXIT': 'plugin',
 'Eggex': 'type-method',
 'Expr': 'type-method',
 'FUNCNAME': 'special-var',
 'Float': 'type-method',
 'Frame': 'type-method',
 'Func': 'type-method',
 'GLOBIGNORE': 'special-var',
 'HISTFILE': 'special-var',
 'HOME': 'special-var',
 'HOSTNAME': 'special-var',
 'IFS': 'special-var',
 'INFINITY': 'special-var',
 'Int': 'type-method',
 'LANG': 'special-var',
 'LIB_OSH': 'special-var',
 'LIB_YSH': 'special-var',
 'LINENO': 'special-var',
 'List': 'type-method',
 'List/append': 'type-method',
 'List/clear': 'type-method',
 'Match': 'type-method',
 'NAN': 'special-var',
 'Null': 'type-method',
 'OILS_GC_ON_EXIT': 'special-var',
 'OILS_GC_STATS': 'special-var',
 'OILS_GC_STATS_FD': 'special-var',
 'OILS_GC_THRESHOLD': 'special-var',
 'OILS_VERSION': 'special-var',
 'OLDPWD': 'special-var',
 'OPTARG': 'special-var',
 'OPTERR': 'special-var',
 'OPTIND': 'special-var',
 'OSTYPE': 'special-var',
 'Obj': 'type-method',
 'PATH': 'special-var',
 'PIPESTATUS': 'special-var',
 'PPID': 'special-var',
 'PROMPT_COMMAND': 'plugin',
 'PS1': 'plugin',
 'PS2': 'plugin',
 'PS3': 'plugin',
 'PS4': 'plugin',
 'PWD': 'special-var',
 'Place': 'type-method',
 'Proc': 'type-method',
 'RANDOM': 'special-var',
 'REPLY': 'special-var',
 'RETURN': 'plugin',
 'Range': 'type-method',
 'SECONDS': 'special-var',
 'SHELLOPTS': 'special-var',
 'SHX_indent': 'special-var',
 'SHX_pid_str': 'special-var',
 'SHX_punct': 'special-var',
 'SIGINT': 'plugin',
 'SIGQUIT': 'plugin',
 'SIGTERM': 'plugin',
 'SIGTTIN': 'plugin',
 'SIGTTOU': 'plugin',
 'SIGWINCH': 'plugin',
 'Str': 'type-method',
 'UID': 'special-var',
 'YSH_HISTFILE': 'special-var',
 '__builtins__': 'special-var',
 '__call__': 'type-method',
 '__defaults__': 'special-var',
 '__index__': 'type-method',
 '__invoke__': 'type-method',
 '__provide__': 'special-var',
 '__str__': 'type-method',
 '_end': 'builtin-func',
 '_error': 'special-var',
 '_group': 'builtin-func',
 '_pipeline_status': 'special-var',
 '_process_sub_status': 'special-var',
 '_reply': 'special-var',
 '_start': 'builtin-func',
 '_status': 'special-var',
 '_this_dir': 'special-var',
 'abs': 'stdlib',
 'accum': 'type-method',
 'alias': 'builtin-cmd',
 'all': 'stdlib',
 'ampersand': 'cmd-lang',
 'and': 'cmd-lang',
 'any': 'stdlib',
 'append': 'index',
 'arg': 'stdlib',
 'arith-context': 'mini-lang',
 'arith-sub': 'word-lang',
 'ascii-control-chars': 'front-end',
 'ascii-whitespace': 'front-end',
 'assert': 'builtin-cmd',
 'assign': 'expr-lang',
 'atom-literal': 'expr-lang',
 'aug-assign': 'expr-lang',
 'b-prefix': 'j8',
 'bang': 'cmd-lang',
 'block-arg': 'cmd-lang',
 'block-expr': 'expr-lang',
 'bool': 'builtin-func',
 'bool-expr': 'mini-lang',
 'bool-infix': 'mini-lang',
 'bool-other': 'mini-lang',
 'bool-path': 'mini-lang',
 'bool-str': 'mini-lang',
 'boolstatus': 'builtin-cmd',
 'braces': 'mini-lang',
 'break': 'cmd-lang',
 'builtin': 'builtin-cmd',
 'bytes': 'builtin-func',
 'call': 'ysh-cmd',
 'captureStdout': 'type-method',
 'case': 'cmd-lang',
 'cat-em': 'front-end',
 'cd': 'builtin-cmd',
 'char-escapes': 'mini-lang',
 'char-literal': 'expr-lang',
 'class-literal': 'expr-lang',
 'clear': 'index',
 'cmd/append': 'builtin-cmd',
 'cmd/false': 'builtin-cmd',
 'cmd/true': 'builtin-cmd',
 'cmd/type': 'builtin-cmd',
 'colon': 'builtin-cmd',
 'column-attrs': 'j8',
 'column-types': 'j8',
 'command': 'builtin-cmd',
 'command-sub': 'word-lang',
 'comment': 'front-end',
 'compadjust': 'builtin-cmd',
 'compexport': 'builtin-cmd',
 'compgen': 'builtin-cmd',
 'complete': 'plugin',
 'compopt': 'builtin-cmd',
 'concat': 'expr-lang',
 'config': 'front-end',
 'const': 'ysh-cmd',
 'continue': 'cmd-lang',
 'ctx': 'builtin-cmd',
 'dashglob': 'option',
 'dbracket': 'cmd-lang',
 'declare': 'osh-assign',
 'dict': 'builtin-func',
 'dict-literal': 'expr-lang',
 'die': 'stdlib',
 'dirs': 'builtin-cmd',
 'doc-comment': 'front-end',
 'dparen': 'cmd-lang',
 'echo': 'builtin-cmd',
 'enable': 'builtin-cmd',
 'encodeBytes': 'builtin-func',
 'encodeRunes': 'builtin-func',
 'end': 'type-method',
 'endsWith': 'type-method',
 'equal': 'ysh-cmd',
 'erase': 'type-method',
 'err-j8-lines-decode': 'errors',
 'err-j8-lines-encode': 'errors',
 'err-j8-str-decode': 'errors',
 'err-j8-str-encode': 'errors',
 'err-json-decode': 'errors',
 'err-json-encode': 'errors',
 'err-json8-decode': 'errors',
 'err-json8-encode': 'errors',
 'err-utf8-decode': 'errors',
 'err-utf8-encode': 'errors',
 'error': 'builtin-cmd',
 'eval': 'type-method',
 'evalExpr': 'type-method',
 'evalHay': 'builtin-func',
 'evalToDict': 'type-method',
 'eval_unsafe_arith': 'option',
 'exec': 'builtin-cmd',
 'exit': 'cmd-lang',
 'exit-codes': 'front-end',
 'export': 'osh-assign',
 'expr-literal': 'expr-lang',
 'expr-splice': 'word-lang',
 'expr-sub': 'word-lang',
 'expr/false': 'type-method',
 'expr/true': 'type-method',
 'extend': 'type-method',
 'extglob': 'mini-lang',
 'failed': 'builtin-cmd',
 'false': 'index',
 'fat-arrow': 'expr-lang',
 'fg': 'builtin-cmd',
 'find': 'type-method',
 'first': 'builtin-func',
 'flag': 'stdlib',
 'float': 'builtin-func',
 'float-literal': 'expr-lang',
 'floatsEqual': 'builtin-func',
 'fopen': 'builtin-cmd',
 'for': 'cmd-lang',
 'for-expr-sh': 'cmd-lang',
 'fork': 'builtin-cmd',
 'forkwait': 'builtin-cmd',
 'fromJson': 'builtin-func',
 'fromJson8': 'builtin-func',
 'func': 'ysh-cmd',
 'func/type': 'builtin-func',
 'get': 'builtin-func',
 'getFrame': 'type-method',
 'getVar': 'builtin-func',
 'getopts': 'builtin-cmd',
 'glob': 'type-method',
 'glob-pat': 'mini-lang',
 'group': 'type-method',
 'hash': 'builtin-cmd',
 'hay': 'builtin-cmd',
 'haynode': 'builtin-cmd',
 'help': None,
 'here-doc': 'cmd-lang',
 'here-str': 'cmd-lang',
 'history': 'builtin-cmd',
 'histsub': 'mini-lang',
 'id': 'type-method',
 'if': 'cmd-lang',
 'ignore_flags_not_impl': 'option',
 'ignore_shopt_not_impl': 'option',
 'indexOf': 'type-method',
 'insert': 'type-method',
 'int': 'builtin-func',
 'int-literal': 'expr-lang',
 'io': 'type-method',
 'is-main': 'builtin-cmd',
 'j8-escape': 'j8',
 'jobs': 'builtin-cmd',
 'join': 'builtin-func',
 'json': 'builtin-cmd',
 'json-escape': 'j8',
 'json-string': 'j8',
 'json8': 'builtin-cmd',
 'json8-comment': 'j8',
 'json8-dict': 'j8',
 'json8-list': 'j8',
 'json8-num': 'j8',
 'json8-str': 'j8',
 'keys': 'builtin-func',
 'kill': 'builtin-cmd',
 'lazy-expr-arg': 'cmd-lang',
 'leftMatch': 'type-method',
 'len': 'builtin-func',
 'line-continuation': 'front-end',
 'line-editing': 'front-end',
 'list': 'builtin-func',
 'list-literal': 'expr-lang',
 'local': 'osh-assign',
 'log': 'stdlib',
 'lower': 'type-method',
 'mapfile': 'builtin-cmd',
 'match-ops': 'expr-lang',
 'max': 'stdlib',
 'maybe': 'builtin-func',
 'min': 'stdlib',
 'multiline-command': 'front-end',
 'named-class': 'expr-lang',
 'new': 'type-method',
 'no-prefix': 'j8',
 'nq-assert': 'stdlib',
 'nq-capture': 'stdlib',
 'nq-capture-2': 'stdlib',
 'nq-redir': 'stdlib',
 'nq-redir-2': 'stdlib',
 'nq-run': 'stdlib',
 'null': 'type-method',
 'nullglob': 'option',
 'oils-usage': None,
 'op-format': 'word-lang',
 'op-index': 'word-lang',
 'op-patsub': 'word-lang',
 'op-precedence': 'expr-lang',
 'op-slice': 'word-lang',
 'op-strip': 'word-lang',
 'op-test': 'word-lang',
 'opts-internal': 'option',
 'opts-redefine': 'option',
 'or': 'cmd-lang',
 'osh-chapters': None,
 'osh-string': 'word-lang',
 'osh-usage': None,
 'parseArgs': 'stdlib',
 'parseCommand': 'builtin-func',
 'parseExpr': 'builtin-func',
 'parseHay': 'builtin-func',
 'parse_ignored': 'option',
 'parse_triple_quote': 'option',
 'parse_ysh_string': 'option',
 'parser': 'stdlib',
 'pipe': 'cmd-lang',
 'pop': 'type-method',
 'popd': 'builtin-cmd',
 'pp': 'builtin-cmd',
 'prefix-binding': 'cmd-lang',
 'printf': 'builtin-cmd',
 'proc': 'ysh-cmd',
 'proc-sub': 'word-lang',
 'promptVal': 'type-method',
 'push-registers': 'builtin-cmd',
 'pushd': 'builtin-cmd',
 'pwd': 'builtin-cmd',
 'range': 'expr-lang',
 're-capture': 'expr-lang',
 're-compound': 'expr-lang',
 're-flags': 'expr-lang',
 're-literal': 'expr-lang',
 're-multiline': 'expr-lang',
 're-primitive': 'expr-lang',
 're-repeat': 'expr-lang',
 're-splice': 'expr-lang',
 'read': 'builtin-cmd',
 'readarray': 'builtin-cmd',
 'readonly': 'osh-assign',
 'redir-desc': 'cmd-lang',
 'redir-file': 'cmd-lang',
 'regex': 'mini-lang',
 'remove': 'type-method',
 'renderPrompt': 'plugin',
 'repeat': 'stdlib',
 'replace': 'type-method',
 'rest': 'stdlib',
 'return': 'cmd-lang',
 'reverse': 'type-method',
 'round': 'stdlib',
 'runes': 'builtin-func',
 'runproc': 'builtin-cmd',
 'search': 'type-method',
 'semicolon': 'cmd-lang',
 'set': 'builtin-cmd',
 'setValue': 'type-method',
 'setVar': 'builtin-func',
 'setglobal': 'ysh-cmd',
 'setvar': 'ysh-cmd',
 'sh-append': 'osh-assign',
 'sh-arith': 'mini-lang',
 'sh-array': 'osh-assign',
 'sh-assign': 'osh-assign',
 'sh-assoc': 'osh-assign',
 'sh-bitwise': 'mini-lang',
 'sh-block': 'cmd-lang',
 'sh-func': 'cmd-lang',
 'sh-logical': 'mini-lang',
 'sh-numbers': 'mini-lang',
 'shSplit': 'builtin-func',
 'sha1dc': 'builtin-func',
 'sha256': 'builtin-func',
 'shift': 'osh-assign',
 'shopt': 'builtin-cmd',
 'shvar': 'builtin-cmd',
 'shvarGet': 'builtin-func',
 'sigpipe_status_ok': 'option',
 'simple-command': 'cmd-lang',
 'source': 'builtin-cmd',
 'source-guard': 'builtin-cmd',
 'split': 'type-method',
 'start': 'type-method',
 'startsWith': 'type-method',
 'startup': 'front-end',
 'stdin': 'type-method',
 'str': 'builtin-func',
 'str-template': 'expr-lang',
 'strcmp': 'builtin-func',
 'strftime': 'type-method',
 'strict:all': 'option',
 'strict_control_flow': 'option',
 'strict_nameref': 'option',
 'strict_tilde': 'option',
 'subshell': 'cmd-lang',
 'sum': 'stdlib',
 'surrogate-pair': 'j8',
 'tagged-str': 'word-lang',
 'task-five': 'stdlib',
 'test': 'builtin-cmd',
 'thin-arrow': 'expr-lang',
 'tilde-sub': 'word-lang',
 'time': 'type-method',
 'times': 'builtin-cmd',
 'toJson': 'builtin-func',
 'toJson8': 'builtin-func',
 'trap': 'builtin-cmd',
 'trim': 'type-method',
 'trimEnd': 'type-method',
 'trimStart': 'type-method',
 'triple-quoted': 'word-lang',
 'true': 'index',
 'try': 'builtin-cmd',
 'type': 'index',
 'typed-arg': 'cmd-lang',
 'typeset': 'osh-assign',
 'u-prefix': 'j8',
 'ulimit': 'builtin-cmd',
 'umask': 'builtin-cmd',
 'unalias': 'builtin-cmd',
 'unquoted-line': 'j8',
 'unset': 'osh-assign',
 'until': 'cmd-lang',
 'upper': 'type-method',
 'use': 'builtin-cmd',
 'values': 'builtin-func',
 'var': 'ysh-cmd',
 'var-splice': 'word-lang',
 'var-sub': 'word-lang',
 'vm': 'type-method',
 'wait': 'builtin-cmd',
 'while': 'cmd-lang',
 'write': 'builtin-cmd',
 'yb-capture': 'stdlib',
 'yb-capture-2': 'stdlib',
 'ysh-arith': 'expr-lang',
 'ysh-attr': 'expr-lang',
 'ysh-bitwise': 'expr-lang',
 'ysh-case': 'cmd-lang',
 'ysh-cd': 'builtin-cmd',
 'ysh-chapters': None,
 'ysh-compare': 'expr-lang',
 'ysh-echo': 'builtin-cmd',
 'ysh-equals': 'expr-lang',
 'ysh-for': 'cmd-lang',
 'ysh-format': 'word-lang',
 'ysh-func-call': 'expr-lang',
 'ysh-here-str': 'cmd-lang',
 'ysh-if': 'cmd-lang',
 'ysh-in': 'expr-lang',
 'ysh-index': 'expr-lang',
 'ysh-logical': 'expr-lang',
 'ysh-prefix-binding': 'cmd-lang',
 'ysh-printf': 'word-lang',
 'ysh-read': 'builtin-cmd',
 'ysh-return': 'ysh-cmd',
 'ysh-shopt': 'builtin-cmd',
 'ysh-slice': 'expr-lang',
 'ysh-string': 'word-lang',
 'ysh-ternary': 'expr-lang',
 'ysh-test': 'builtin-cmd',
 'ysh-usage': None,
 'ysh-while': 'cmd-lang',
 'ysh:all': 'option',
 'ysh:upgrade': 'option'}


from typing import Dict

def TopicMetadata():
  # type: () -> Dict[str, str]
  return TOPICS
